/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#ifndef MAP_H
#define MAP_H

#include <qobject.h>
#include <qlist.h>

#include "krepton.h"

class KAudio;

enum Orientation { North, South, East, West };

struct Monster {
	int xpos, ypos;
	SpriteObj type;
	SpriteObj sprite;
	Orientation orientation;

	Monster(int x, int y, SpriteObj t)
		: xpos(x), ypos(y),
		  type(t), sprite(t),
		  orientation(West) {}
};

struct Transporter {
	int orig_x, orig_y;
	int dest_x, dest_y;

	Transporter(int ox, int oy, int dx, int dy)
		: orig_x(ox), orig_y(oy),
		  dest_x(dx), dest_y(dy) {}
};

class Map {
public:
	int width, height;
	QString password;
	SpriteObj *data;

	QList<Monster> monsters;
	QList<Transporter> transporters;

	int xpos, ypos;		// Repton position
	SpriteObj sprite;
	int num_diamonds;
	int num_secs;
	int num_points;
	bool have_key;
	bool status_die, status_end_level;
	bool *do_sounds;

	Map();
	~Map();

	SpriteObj& ref(int x, int y) {
		return data[y*width + x];
	}
	SpriteObj xy(int x, int y) {
		if (x < 0 || y < 0 || x >= width || y >= height)
			return Obj_Wall;
		return ref(x, y);
	}
	bool isempty(int x, int y) {
		switch (xy(x, y)) {
		case Obj_Empty:
		case Obj_Ground1:
		case Obj_Ground2:
			return true;
		default:
			return false;
		}
	}

	void loadData(const QString& filename);

	void addTransporter(int ox, int oy, int dx, int dy);
	Transporter *findTransporter(int x, int y);
	void addMonster(int x, int y, SpriteObj type);
	void prepareMonsters();
	Monster *findMonster(int x, int y);

	void goUp() { moveVertical(-1); }
        void goDown() { moveVertical(1); }
	void goLeft() { moveHorizontal(-1); }
	void goRight() { moveHorizontal(1); }
	void updateEggs();
	void updateObjects();
	void updateMonsters();
	void updatePlants();

private:
	KAudio *audio;

	void playSound(Sound s);
	void deleteTransporters();
	void deleteMonsters();
	bool tryFallDown(int x, int y);
	bool tryFallHorizontal(int x, int y, int xd);
	void tryFallLeftOrRight(int x, int y);
	void tryFall(int x, int y);
	bool blipTryDirection(Monster *m, Orientation dir, int xd, int yd);
	void updateBlip(Monster *m);
	double monsterTryDirection(Monster *m, int xd, int yd);
	void updateMonster(Monster *m);
	bool tryPlant(int x, int y, int dx, int dy);
	bool updatePlant(Monster *m);
	void moveVerticalDirect(int yd);
	void moveHorizontalDirect(int xd);
	void gotKey();
	void gotObject(SpriteObj obj);
	void useTransporter(int x, int y);
	void moveVertical(int yd);
	void moveHorizontalMoveObj(int xd, SpriteObj obj);
	void moveHorizontal(int xd);
	void killMonster(Monster *mp);
	void cageBlip(Monster *m, int x, int y);
};

#endif // !MAP_H
