/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#include "config.h"

#include <kapp.h>
#include <qlined.h>
#include <qpushbt.h>
#include <qlabel.h>
#include <qlistbox.h>
#include <qtooltip.h>

#include "mainwidget.h"

MainWidget::MainWidget(QWidget *parent = 0, const char *name = 0)
	: QWidget(parent, name)
{
	setFixedSize(350, 380);

	name_edit = new QLineEdit(this);
	name_edit->setGeometry(100, 10, 100, 30);
	QToolTip::add(name_edit, "The name used in the KRepton game for referencing the episode");
	QLabel *label = new QLabel(name_edit, "Episode &name", this);
	label->setAutoResize(true);
	label->move(10, 15);

	maps_list = new QListBox(this);
	maps_list->setGeometry(10, 80, 150, 100);
	QToolTip::add(maps_list, "The list of levels of the episode");
	label = new QLabel(maps_list, "&Maps list", this);
	label->setAutoResize(true);
	label->move(10, 60);

	map_insert = new QPushButton("&Insert", this);
	map_insert->setGeometry(170, 80, 80, 30);
	QToolTip::add(map_insert, "Insert a new level");
	map_remove = new QPushButton("&Remove", this);
	map_remove->setGeometry(260, 80, 80, 30);
	QToolTip::add(map_remove, "Remove a level");
	map_move_up = new QPushButton("Move &Up", this);
	map_move_up->setGeometry(170, 120, 80, 30);
	QToolTip::add(map_move_up, "Move a level one position up");
	map_move_down = new QPushButton("Move &Down", this);
	map_move_down->setGeometry(260, 120, 80, 30);
	QToolTip::add(map_move_down, "Move a level one position down");

	password_edit = new QLineEdit(this);
	password_edit->setGeometry(70, 200, 90, 30);
	QToolTip::add(password_edit, "The password of the current level");
	label = new QLabel(password_edit, "&Password", this);
	label->setAutoResize(true);
	label->move(10, 205);

	time_edit = new QLineEdit(this);
	time_edit->setGeometry(230, 200, 90, 30);
	QToolTip::add(time_edit, "The time limit (in seconds) of the current level");
	label = new QLabel(time_edit, "Time &limit", this);
	label->setAutoResize(true);
	label->move(170, 205);

	transporters_list = new QListBox(this);
	transporters_list->setGeometry(10, 270, 150, 100);
	QToolTip::add(transporters_list, "The transporters of the current level");
	label = new QLabel(transporters_list, "&Transporters list", this);
	label->setAutoResize(true);
	label->move(10, 250);

	transporter_insert = new QPushButton("In&sert", this);
	transporter_insert->setGeometry(170, 270, 80, 30);
	QToolTip::add(transporter_insert, "Insert a new transporter");
	transporter_remove = new QPushButton("R&emove", this);
	transporter_remove->setGeometry(260, 270, 80, 30);
	QToolTip::add(transporter_remove, "Remove a transporter");

	maps_list->setFocus();
}
